#
# spec file for package fontforge
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fontforge
Version:        20120731
Release:        15.32
%define src_version %{version}-b
Summary:        A Font Editor
License:        BSD-3-Clause
Group:          Productivity/Graphics/Vector Editors
Url:            http://fontforge.org/

Source0:        http://downloads.sourceforge.net/%{name}/%{name}_full-%{src_version}.tar.bz2
Source1:        http://downloads.sourceforge.net/%{name}/%{name}_htdocs-%{src_version}.tar.bz2
# PATCH-FIX-OPENSUSE -- set path to documentation
Patch0:         docdir.patch
Patch1:         fontforge-20090622-fdleak.patch
Patch2:         libpng14-dynamic.diff
# PATCH-FIX-OPENSUSE fontforge-python-module-name.diff -- change python module name according to naming policy
Patch3:         fontforge-python-module-name.diff
Patch4:         fontforge-fixgiflib.patch
Patch5:         fontforge-eof-crash.patch

BuildRequires:  cairo-devel
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gettext-tools
BuildRequires:  giflib-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
%if 0%{?suse_version} > 1210
BuildRequires:  libspiro-devel
%endif
BuildRequires:  libtiff-devel
BuildRequires:  libuninameslist-devel
BuildRequires:  libxml2-devel
BuildRequires:  pango-devel
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
# following to avoid warning
# 'Application built with libpng-1.5.14 but running with 1.6.1'
%requires_eq	libpng16-16
Obsoletes:      PfaEdit < 20110222
Provides:       PfaEdit = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FontForge allows editing of outline and bitmap fonts.  With it, you can
create new fonts or modify old ones.  It also converts font formats and
can convert among PostScript (ASCII & binary Type 1, some Type 3s, and
some Type 0s), TrueType, OpenType (Type2), and CID-keyed fonts.

%package doc
Summary:        Documentation for FontForge
Group:          Documentation/HTML
%if 0%{?suse_version} >= 1230
BuildArch:      noarch
%endif

%description doc
FontForge allows editing of outline and bitmap fonts. With it, you can
create new fonts or modify old ones. It also converts font formats and
can convert among PostScript, TrueType, OpenType, and CID-keyed fonts.

This subpackage contains the documentation to FontForge.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       freetype2-devel

%description devel
FontForge allows editing of outline and bitmap fonts. With it, you can
create new fonts or modify old ones. It also converts font formats and
can convert among PostScript, TrueType, OpenType, and CID-keyed fonts.

This subpackage contains all necessary include files and libraries needed
to develop applications that use FontForge libraries.

%prep
%setup -q -T -n fontforge-%{src_version} -b 0
%patch0 -p 1 -b .docdir
%patch1
%if 0%{?suse_version} > 1120
%patch2
%endif
%patch3
%if 0%{?suse_version} > 1230
%patch4 -p1
%patch5
%endif

mkdir docs
tar -jxvf %{SOURCE1} -C docs
chmod 644 docs/quadraticspline.gif
chmod 644 docs/FontForgeSplash.png
chmod 644 docs/*.html
# tar zxvf docs/cidmaps.tgz
find . -name CVS -type d | xargs rm -rf
# fix wrong-file-end-of-line-encoding
sed -i 's/\r$//' docs/{Big5.txt,corpchar.txt}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
    --disable-static \
    --enable-pyextension \
    --with-regular-link

make %{?_smp_mflags}

pushd pyhook
python setup.py build
popd

%install
make DESTDIR=%{buildroot} install
# symlink for old FontForge name - PfaEdit
pushd %{buildroot}%{_bindir}
    ln -s fontforge pfaedit
popd
# install CMaps to be able to edit CID-keyed fonts:
# install -m 644 Adobe* %{buildroot}%{_datadir}/fontforge

# desktop file and icon
install -Dm 644 Packaging/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 644 Packaging/icons/48x48/apps/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%suse_update_desktop_file -i %{name} VectorGraphics

%find_lang FontForge
rm -f %{buildroot}%{_libdir}/*.la

pushd pyhook
python setup.py install \
   --root=%{buildroot} \
   --prefix=%{_prefix} \
   --record-rpm=%{name}-python.files
popd

%fdupes -s %{buildroot}%{_datadir}/%{name}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f FontForge.lang
%defattr(-,root,root)
%doc LICENSE
%{_bindir}/*
%{_libdir}/lib*.so.*
%{_datadir}/fontforge/
%{_mandir}/man1/*.1*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%py_sitedir/*

%files doc
%defattr(-,root,root)
%doc AUTHORS VERSION LICENSE README-unix docs/

%files devel
%defattr(-, root, root)
%{_includedir}/fontforge/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/lib*.so

%changelog
* Tue Jan 26 2016 pgajdos@suse.com
- do not crash on invalid input data (when eof reached) [bnc#963023]
  + fontforge-eof-crash.patch
* Thu Nov 14 2013 jengelh@inai.de
- Put documentation into a separate subpackage
- Spruce of description of fontforge-devel a bit
- File list simplification/exactness
* Mon Sep  9 2013 coolo@suse.com
- add fontforge-fixgiflib.patch to fix build with giflib 5.0.5
* Tue Apr 16 2013 pgajdos@suse.com
- use %%requires_eq rather than %%requires_ge (exact version)
* Tue Apr 16 2013 pgajdos@suse.com
- %%requires_ge libpng16-16 to avoid
  'Application built with libpng-1.5.14 but running with 1.6.1'
  warning when running fontforge
* Fri Jan  4 2013 dmitry_r@opensuse.org
- Build with cairo and pango support
* Sun Dec 30 2012 dmitry_r@opensuse.org
- Update to 20120731b
  * see included changelog.html for details
  * removed obsolete fontforge.py27.diff
  * removed obsolete fontforge-missing-closedir.diff
  * removed obsolete libpng14.diff
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon Oct  3 2011 pgajdos@suse.com
- Make rpmlint more happy.
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon May 16 2011 pgajdos@suse.cz
- updated to 20110222:
  * Did a lot of work to improve the accuracy in remove overlap.
  * Fix various error messages.
  * Remove some obsolete documentation.
  * Technical fixes to stroking code.
  * Add a miterlimit to stroking code.
  * FontForge was using the wrong MIME type for svg files.
    W3C has changed it and it's now "image/svg+xml" not
    "image/svg-xml" or "image/svg".
  * etc. on
    http://fontforge.sourceforge.net/changelog.html
  * libpng14.diff and fontforge.py27.diff kept but not needed yet
* Mon Sep  6 2010 coolo@novell.com
- adapt to python 2.7
* Thu Apr  8 2010 tiwai@suse.de
- fix build with older distros before libpng 1.4
* Thu Apr  8 2010 coolo@novell.com
- compile with libpng 1.4
* Mon Apr  5 2010 toms@suse.de
- Updated to 20090923
- Enabled Python bindings
* Sat Oct  3 2009 crrodriguez@opensuse.org
- fontforge-20090622-1.6: missing call to closedir  [bnc#543458]
- fix -devel package dependencies
* Mon Jul 27 2009 tiwai@suse.de
- fix missing closedir() (bnc#525022)
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 20090622
  lots of changes.  See changelog.html for details
* Wed Jan 21 2009 crrodriguez@suse.de
- remove "la" files and static libraries
- add missing freetype2-devel dependency to -devel package
* Mon May 26 2008 mfabian@suse.de
- bnc#246804: update to 20080429 (needed to build recent versions
  of the DejaVu fonts and freefont).
* Fri Feb 29 2008 coolo@suse.de
- fix typo
* Thu Feb 21 2008 mfabian@suse.de
- update to 20080203 (bugfix release, fixes also bnc#363014).
- create -devel sub-package.
* Thu Aug  2 2007 mfabian@suse.de
- update to 20070723 (user interace redesigned, many bugfixes).
- add ldconfig post scripts.
- remove executable flags from documentation.
- remove DOS line-endings from documentation.
* Tue Jul 24 2007 coolo@suse.de
- remove BuildPreRequires
* Tue Feb  6 2007 mfabian@suse.de
- Bugzilla #242363: uninitialized variable.
* Wed Jan  3 2007 mfabian@suse.de
- update to 20061220.
- remove fontforge-strncat.patch,
  bugzilla-221210-locale-variable-used-before-set.patch,
  bugzilla-225616-local-variable-used-before-set.patch
  (included upstream).
- fix bugzilla #231126: "array subscript out of range".
* Tue Dec 19 2006 mfabian@suse.de
- update to 20061025.
  • fontimage program has been added.
- fix bugzilla #225616 ("local variable used before set").
* Fri Nov 17 2006 mfabian@suse.de
- Bugzilla #221210: "local variable used before set"
* Sun Nov  5 2006 ro@suse.de
- fix permissions on icon file
- fix gcc warning for strncat
* Tue Oct 17 2006 mfabian@suse.de
- update to 20061014.
  remove bugzilla-203490-local-variable-used-before-set.patch
  (included upstream).
- Fix Bugzilla #211543 ("array subscript out of range).
- Fix invalid operation (like x = x++;)
* Thu Sep  7 2006 mfabian@suse.de
- fix bugzilla #203490: "local variable used before set".
- add Japanese documentation.
* Wed Sep  6 2006 mfabian@suse.de
- update to 20060822.
  remove bugzilla-197499-local-variable-used-before-set.patch
  (included upstream).
* Thu Aug 10 2006 mfabian@suse.de
- Bugzilla 197499: "local variable used before set".
* Tue Jul 18 2006 mfabian@suse.de
- update to 20060715.
  fixes a crash when building freefont.
* Fri Mar 17 2006 mfabian@suse.de
- Bugzilla #158759: "locale variable used before set".
  (already fixed in latest upstream version).
* Thu Mar  9 2006 mfabian@suse.de
- Bugzilla #153958: "array subscript out of range".
  (already fixed in latest upstream version).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Oct  2 2005 stbinner@suse.de
- fix capitalization of .desktop GenericName entry
* Thu Aug  4 2005 mfabian@suse.de
- update to 20050803.
  cannot update documentation because the download link for the
  documentation is currently dead.
* Wed May 11 2005 mfabian@suse.de
- update to 20050502.
- all .html and .png files should have mode 644.
- fix fontforge.desktop file (thanks to
  Thomas Schraitle<thomas.schraitle@suse.de>).
* Tue Dec 14 2004 hvogel@suse.de
- install icon
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed Aug 18 2004 mfabian@suse.de
- rename: PfaEdit -> fontforge (has been renamed upstream).
- update to 20040808.
* Sun Apr 25 2004 ro@suse.de
- use no-strict-aliasing
* Thu Feb 26 2004 mfabian@suse.de
- update to 040224.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sat Aug 23 2003 mfabian@suse.de
- make it build on older distributions.
* Mon Aug 18 2003 mfabian@suse.de
- update to 030817.
- add desktop file.
* Fri May 16 2003 mfabian@suse.de
- update binaries and documentation to 030512
- add .so and .la file to file list
- add "freetype2 freetype2-devel" to neededforbuild
* Wed Feb 12 2003 mfabian@suse.de
- update binaries and documentation to 030211
* Wed Nov 13 2002 mfabian@suse.de
- update to 021105
- use x-devel-packages instead of xf86 in # neededforbuild
- use dynamic linking
* Tue Oct 22 2002 mfabian@suse.de
- update to 021021 and update documentation to 020910.
* Fri Jul 26 2002 mfabian@suse.de
- update to version 020724
- include documentation, remove cidmaps.tar.bz2 and use updated
  cidmaps.tgz from the documentation tar ball
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan 22 2002 mfabian@suse.de
- update to version 020121.
- updated cidmaps.tar.bz2
* Wed Sep  5 2001 mfabian@suse.de
- adapted for SuSE, version 010905
* Thu May 10 2001 George Williams <gww@silcom.com>
- My first attempt at rpm, updated to 10 May sources
* Tue May  1 2001 Scott Pakin <pakin@uiuc.edu>
- Removed (unused) dynamic library files
* Sun Apr 29 2001 Scott Pakin <pakin@uiuc.edu>
- Upgraded from 220401 to 280401.
* Tue Apr 24 2001 Scott Pakin <pakin@uiuc.edu>
- Upgraded from 190401 to 220401.
* Fri Apr 20 2001 Scott Pakin <pakin@uiuc.edu>
- Upgraded from 020401 to 190401.
* Tue Apr 10 2001 Scott Pakin <pakin@uiuc.edu>
- Upgraded from 210301 to 020401.
* Thu Mar 22 2001 Scott Pakin <pakin@uiuc.edu>
- Initial release
